# Generated by Django 3.2 on 2021-05-03 17:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('generic_forms', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='formbuilder',
            name='content',
        ),
    ]
